#
# spec file for package libsrtp2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libsrtp2
%define lname	libsrtp2-1
Version:        2.5.0
Release:        2.1
Summary:        Secure Real-Time Transport Protocol (SRTP) library v2
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/cisco/libsrtp

Source:         https://github.com/cisco/libsrtp/archive/v%version.tar.gz
Source99:       baselibs.conf
Patch1:         libsrtp2-test-verbose.patch
BuildRequires:  libpcap-devel
BuildRequires:  pkg-config
BuildRequires:  procps
BuildRequires:  pkgconfig(openssl) >= 1.1.0

%description
libsrtp is Cisco's implementation of the Secure Real-time Transport
Protocol (SRTP), the Universal Security Transform (UST), and a
supporting cryptographic kernel.

%package -n %lname
Summary:        Secure Real-Time Transport Protocol (SRTP) library v2
Group:          System/Libraries

%description -n %lname
libsrtp is Cisco's implementation of the Secure Real-time Transport
Protocol (SRTP), the Universal Security Transform (UST), and a
supporting cryptographic kernel.

SRTP is a security profile for RTP that adds confidentiality, message
authentication, and replay protection to that protocol. It is
specified in RFC 3711. More information about the SRTP protocol
itself can be found on the Secure RTP page.

%package devel
Summary:        Development files for the Secure Real-Time Transport Protocol (SRTP) library v2
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libsrtp is Cisco's implementation of the Secure Real-time Transport
Protocol (SRTP), the Universal Security Transform (UST), and a
supporting cryptographic kernel.

This subpackage contains the development headers.

%prep
%autosetup -p1 -n libsrtp-%version

%build
%configure --enable-openssl
%make_build shared_library

%install
%make_install

%check
%make_build runtest

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libsrtp2.so.1

%files devel
%doc CHANGES README.md doc/*.txt
%license LICENSE
%_includedir/srtp2/
%_libdir/libsrtp2.so
%_libdir/pkgconfig/libsrtp2.pc

%changelog
* Tue Apr 25 2023 Pedro Monreal <pmonreal@suse.com>
- Enable running the regression tests:
  * Add libsrtp2-test-verbose.patch from the debian folks:
    https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=460534
* Wed Feb  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.5.0
  * No changelog provided; some unspecified crypto updates occurred.
* Wed May  4 2022 Jan Engelhardt <jengelh@inai.de>
- Remove include header editing; the issue once present in
  libsrtp 2.0.0 seems reasonably resolved in current 2.4.2
  [boo#1198887]
* Tue Sep 21 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.2
  * Fixes an unspecified regression introduced in 2.4.1
* Thu Sep  9 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.1
  * Use a full-length key even with null ciphers
* Sat Aug 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.0
  * Remove EKT files, this was never completed and the draft has
    since changed.
- Remove 0001-Adjust-.pc-file-not-to-expose-used-crypto-library.patch
  (merged)
* Sat May 15 2021 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Adjust-.pc-file-not-to-expose-used-crypto-library.patch
  [boo#1185931]
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.3.0
  * Changes to build system: fuzzer for libsrtp, NSS
    as optional crypto back end and cmake build support.
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.2.0
  * Stylistic code changes only.
* Tue Aug  1 2017 jengelh@inai.de
- Update to new upstream release 2.1.0
  * Cipher type cleanup for AES. When libSRTP is compiled with
    OpenSSL and the AES 256 ICM cipher is used with RTCP, an
    incorrect initialization vector is formed. This change will
    break backwards compatibility with older versions (1.5, 2.0)
    of libSRTP when using the AES 256 ICM cipher with OpenSSL for
    RTCP.
  * Sequence number incorrectly masked for AES GCM IV. The
    initialization vector for AES GCM encryption was incorrectly
    formed on little endian machines. This change will break
    backwards compatibility with older versions (1.5, 2.0) of
    libSRTP when using the AES GCM cipher for RTCP.
  * Fix OOB read in key generation for encrypted headers with GCM
    ciphers. Adds padding of GCM salt to the corresponding ICM
    length used for header encryption. This change will break
    backwards compatibility with version 2.0 of libSRTP when
    using the header encryption extension with the AES GCM
    cipher.
  * Master Key Identifiers (MKI) Support - for 4 keys.
  * Report SSRC instead of srtp_stream_t in srtp_event_data_t.
  * Fix incorrect structure declarations for (S)RTP and (S)RTCP
    for big endian machines
* Mon Nov 21 2016 jengelh@inai.de
- Update to new 2.x generation, initial release 2.0.0
  * Massively smaller SDK, function names and types were cleaned
    and prefixed.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 1.5.4:
  * Use BE byte ordering of RTCP trailer.
  * Allow zero length payload on unprotect.
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream release 1.5.3
  * Maintenance release, including fix for CVE-2015-6360.
* Wed Jul 29 2015 dimstar@opensuse.org
- Add baselibs.conf: build libsrtp1-32bit, as needed by
  libmediastreamer_voip4-32bit.
* Sun Mar 15 2015 sor.alexei@meowr.ru
- Update to 1.5.2.
- Remove srtp-soname.diff as upstream now defines ABI in filenames
  correctly.
- Spec cleanup.
* Sat Jan  3 2015 jengelh@inai.de
- Update to new upstream release 1.5.0
  * Add support for OpenSSL crypto
  * Add support for AES-GCM crypto suites.
  * Add user data API to allow user to associate additional data
  with a SRTP context.
- Replace libsrtp-automake.patch by simpler srtp-soname.diff
* Thu Aug 28 2014 jengelh@inai.de
- Relax build restrictions for SLE11 (needs BuildRequires xz to
  even start, and we can drop dist-xz from the suggestive patch
  so that automake ~1.10)
* Tue Aug 26 2014 jengelh@inai.de
- Update project metadata, and patch description
* Wed Sep 18 2013 sbrabec@suse.cz
- Upgrade to the latest git snapshot of the version 1.4.5 from the
  new Cisco GIT repository:
  * support for Encrypted Key Transport (EKT)
  * AES-256 support
  * support for packet retransmission
  * API and ABI changes to support new features
  * many bug, crash and memory corruption fixes
  * several security fixes (CVE-2013-2139, bnc#828009)
- Increment shared library version, there are incompatible API and
  ABI changes.
- Rename the package to libsrtp, as did the upstream
- Port and rename srtp-automake.diff to libsrtp-automake.patch.
- Fix headers to not point to private not installed files
  (bnc#839475).
* Wed Oct 31 2012 jengelh@inai.de
- Fold the pkgconfig file into srtp-automake.diff
- Have libsrtp-devel depend on library package
* Wed Oct 31 2012 mailaender@opensuse.org
- Have the package provide a pkg-config file, and run ldconfig
  for the library package
* Tue Oct 25 2011 jengelh@medozas.de
- Remove redundant %%clean section
- Add automake patch so as to properly create shared libraries
* Tue Mar  8 2011 chris@computersalat.de
- spec-cleaner
- remove author from description
- rpmlint: wrong-file-end-of-line-encoding
* Sat Aug  8 2009 alexandre@exatati.com.br
- Version update to 1.4.4 and bzipped source.
  o sorry but CHANGES file is outdated
* Mon Jan 28 2008 sbrabec@suse.cz
- Generate package named srtp-devel.
* Tue Jun  5 2007 ro@suse.de
- suppress devel file warnings, we only have a static lib here
* Wed Jun 28 2006 sbrabec@suse.cz
- New SuSE package, version 1.4.2.
